Infrared Orange documentation
=============================

Contents:

.. toctree::
   :maxdepth: 2

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/curves

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

